

library(lme4)


#compare morphology between the species
Morphology<-read.table("Morphology.csv",sep=";",header=TRUE)
t.test(Morphology$Total~Morphology$Species)
var.test(Morphology$Total~Morphology$Species)
#rotate through different morphology measures


#main analyses
MeanData<-read.table("MeanPMVCLList.csv",sep=";",header=TRUE)
MeanData$fblock<-as.factor(MeanData$block)


#relating sperm velocity to male species, treatment
MeanDataVCL<-subset(MeanData, MinNGoodMotileAllTrts>19) #ensure adequate sample size
MeanDataVCL<-subset(MeanDataVCL, duplicatedPair!="second") #to exclude the second experiment with one male-female pair 
print(Aug11Final<-lmer(vcl~maleSp*date+FemSp2+location+
                   (1|male)+(1|FemaleBand2),data=MeanDataVCL))

print(Aug11Finalb<-lmer(vcl~maleSp*date+location+
                         (1|male)+(1|FemaleBand2),data=MeanDataVCL))
anova(Aug11Final, Aug11Finalb) #test for significance of the removed variable; rotate through by variable.


#for looking at how control velocity relates to velocity in other treatments
MeanDataVCLFems<-subset(MeanDataVCL, FemSp!="ctrl") #because control data enters model differently
summary(Aug11Final<-lmer(CentVCLgm~maleSp*FemSp*CentCrtlVCLgmPrt+date+
                         (1|male)+(1|FemaleBand2),data=MeanDataVCL))

#for testing variances in different species combinations
tapply(MeanDataVCL$CentVCLgm , MeanDataVCL$SpComb1, var) #calculate variances

#chose one combination of treatments to compare variances in a pairwise fashion. Here,
#domesticus males and domesticus females.
DomMaleDomFem<-subset(MeanDataVCL, maleSp=="dom")
DomMaleDomFem<-subset(DomMaleDomFem, FemSp!="hisp")
DomMaleDomFem<-subset(DomMaleDomFem, duplicatedPair!="secondCtrl") #this removal only necessary for house male-house female
#comparison
var.test( DomMaleDomFem$CentVCLgm~DomMaleDomFem$FemSp, na.rm=T)
#rotate through other male-female species combinations; follow similar procedure to test for PM



#Main analyses on the proportion of motile cells
MeanDataPM<-subset(MeanData, Min_total>19)
MeanDataPM<-subset(MeanDataPM, duplicatedPair!="second") #to exclude the second experiment with one male-female pair 

print(Aug11Final<-lmer(asin(PM)~maleSp+date+FemSp2+location+
                         (1|maleBand)+(1|FemaleBand2),data=MeanDataPM))

print(Aug11Finalb<-lmer(asin(PM)~maleSp+protocol+location+
                          (1|maleBand)+(1|FemaleBand2),data=MeanDataPM))
anova(Aug11Final, Aug11Finalb)

#for looking at how control velocity relates to velocity in other treatments
summary(Aug11Final<-lmer(CentPM~maleSp*FemSp*CentCtrlPMGMprto+date+
                           (1|male)+(1|FemaleBand2),data=MeanDataPM))



#single cell data for looking at complete blocks, and the amount of variation explained by male-female combination
VCLtable<-read.table("VCLSingleCell.csv",sep=";",header=TRUE)
VCLtable$fblock<-as.factor(VCLtable$block)

GoodVCL<-subset(VCLtable, MinMotileNTreatment > 19)
May11Exp<-subset(GoodVCL, protocol=="May11")
Aug11Exp<-subset(GoodVCL, protocol=="aug.11")
#note that there were too few data in Protocol 3 to conduct these tests. 

#August 2011
table(Aug11ComplBlocks$maleSp, Aug11ComplBlocks$fblock) #see which blocks lack data for one male species

Aug11ComplBlocks<-subset(Aug11Exp, fblock!="10") #remove the block without complete data
Aug11ComplBlocks<-subset(Aug11ComplBlocks, CtrlFem=="female")
print(Aug11Final<-lmer(vcl~maleSp*ConHetCtrl+location+
                         (1|fblock/maleBand)+(1|fblock/FemaleBand2)+(1|fblock/maleBand:FemaleBand2),data=Aug11ComplBlocks))
print(Aug11Finalb<-lmer(vcl~maleSp*ConHetCtrl+location+
                          (1|fblock/maleBand)+(1|fblock/FemaleBand2)+(1|fblock),data=Aug11ComplBlocks))
anova(Aug11Final, Aug11Finalb)

#May 2011
table(May11ComplBlocks$fblock, May11ComplBlocks$maleSp) #see which blocks lack data for one male species

May11ComplBlocks<-subset(May11Exp, fblock!="4")  #remove the block without complete data
May11ComplBlocks<-subset(May11ComplBlocks, CtrlFem=="female")
print(May11Final<-lmer(vcl~maleSp*ConHetCtrl+location+
                         (1|fblock/maleBand)+(1|fblock/FemaleBand2)+(1|fblock/maleBand:FemaleBand2),data=May11ComplBlocks))    
print(May11Finalb<-lmer(vcl~maleSp*ConHetCtrl+location+
                          (1|fblock/maleBand)+(1|fblock/FemaleBand2)+(1|fblock),data=May11ComplBlocks))     
anova(May11Final, May11Finalb)



#Protein analyses 
ProteinsFull<-read.table("ProteinBands.csv",sep=";",header=TRUE)

ProteinsFull<-subset(ProteinsFull, ExcludeProtein!="y" ) #remove failed assays

#subset by protocol because different variables were useful in different protocols
ProteinsMay2011<-subset(ProteinsFull,Date=="May 2011" )
ProteinsAug2011<-subset(ProteinsFull,Date=="aug.11" )
ProteinsAug2012<-subset(ProteinsFull,Date=="aug.12" )
ProteinsAug2012Cons<-subset(ProteinsAug2012, ExcludeProtein!="second" ) #this removes the 
#second observation of the male-female pair that was used twice; use the value first
#to instead remove the first  (which is in May 2011)

#test for methodological factors possibly relating to protein concentration in sample
cor.test(ProteinsMay2011$Total, ProteinsMay2011$FluidVol, method="spearman")
cor.test(ProteinsAug2011$Total, ProteinsAug2011$Nflushes, method="spearman")
cor.test(ProteinsAug2012$Total, ProteinsAug2012$Nflushes, method="spearman")

#test for how protein content relates to the fluid's effect on sperm swimming behavior

#conspecifics vcl
cor.test(ProteinsMay2011$Total, ProteinsMay2011$ConspVCLdiff, method="spearman", na.rm=T)
cor.test(ProteinsAug2011$Total, ProteinsAug2011$ConspVCLdiff, method="spearman", na.rm=T)
cor.test(ProteinsAug2012Cons$Total, ProteinsAug2012Cons$ConspVCLdiff, method="spearman", na.rm=T)

#conspecifics pm
cor.test(ProteinsMay2011$Total, ProteinsMay2011$ConspPMdiff, method="spearman", na.rm=T)
cor.test(ProteinsAug2011$Total, ProteinsAug2011$ConspPMdiff, method="spearman", na.rm=T)
cor.test(ProteinsAug2012Cons$Total, ProteinsAug2012Cons$ConspPMdiff, method="spearman", na.rm=T)

#heterospecifics vcl
cor.test(ProteinsMay2011$Total, ProteinsMay2011$HeteroVCLdiff, method="spearman", na.rm=T)
cor.test(ProteinsAug2011$Total, ProteinsAug2011$HeteroVCLdiff, method="spearman", na.rm=T)
cor.test(ProteinsAug2012$Total, ProteinsAug2012$HeteroVCLdiff, method="spearman", na.rm=T)

#heterospecifics pm
cor.test(ProteinsMay2011$Total, ProteinsMay2011$HeteroPMdiff, method="spearman", na.rm=T)
cor.test(ProteinsAug2011$Total, ProteinsAug2011$HeteroPMdiff, method="spearman", na.rm=T)
cor.test(ProteinsAug2012$Total, ProteinsAug2012$HeteroPMdiff, method="spearman", na.rm=T)



